# Kutubhona 📚

**Kutubhona** — bu O'zbekistonning zamonaviy Python kutubxonasi! 🎉  
Kutubhona dasturchilarga qulay interfeys orqali ma'lumotlar bilan ishlash imkonini beradi. Bu kutubxona O'zbekistondagi dasturchilar ehtiyojlarini hisobga olgan holda ishlab chiqilgan.  

---

## 📦 O'rnatish

Kutubxonani o'rnatish juda oson:

```bash
pip install weatheruz
